@@ -23,30 +23,31 @@ import javax.jms.Destination;
 import javax.jms.Message;
 import javax.jms.MessageListener;
 import javax.jms.Session;
+import java.io.BufferedOutputStream;
 import java.io.FileOutputStream;
 import java.io.OutputStream;
 
-import com.github.rvesse.airline.annotations.Command;
-import com.github.rvesse.airline.annotations.Option;
 import org.apache.activemq.artemis.cli.commands.ActionContext;
 import org.apache.activemq.artemis.cli.factory.serialize.MessageSerializer;
+import picocli.CommandLine.Command;
+import picocli.CommandLine.Option;
 
 @Command(name = "consumer", description = "Consume messages from a queue.")
 public class Consumer extends DestAbstract {
 
-   @Option(name = "--durable", description = "Whether the consumer's subscription will be durable.")
+   @Option(names = "--durable", description = "Whether the consumer's subscription will be durable.")
    boolean durable = false;
 
-   @Option(name = "--break-on-null", description = "Stop consuming when a null message is received.")
+   @Option(names = "--break-on-null", description = "Stop consuming when a null message is received.")
    boolean breakOnNull = false;
 
-   @Option(name = "--receive-timeout", description = "Timeout for receiving messages (in milliseconds).")
+   @Option(names = "--receive-timeout", description = "Timeout for receiving messages (in milliseconds).")
    int receiveTimeout = 3000;
 
-   @Option(name = "--filter", description = "The message filter.")
+   @Option(names = "--filter", description = "The message filter.")
    String filter;
 
-   @Option(name = "--data", description = "Serialize the messages to the specified file as they are consumed.")
+   @Option(names = "--data", description = "Serialize the messages to the specified file as they are consumed.")
    String file;
 
    @Override
@@ -55,6 +56,8 @@ public class Consumer extends DestAbstract {
 
       context.out.println("Consumer:: filter = " + filter);
 
+      OutputStream outputStream = null;
+
       SerialiserMessageListener listener = null;
       MessageSerializer serializer = null;
       if (file != null) {
@@ -64,15 +67,14 @@ public class Consumer extends DestAbstract {
             return null;
          }
 
-         OutputStream out;
          try {
-            out = new FileOutputStream(file);
+            outputStream = new BufferedOutputStream(new FileOutputStream(file));
          } catch (Exception e) {
             System.err.println("Error: Unable to open file for writing\n" + e.getMessage());
             return null;
          }
 
-         listener = new SerialiserMessageListener(serializer, out);
+         listener = new SerialiserMessageListener(serializer, outputStream);
          serializer.start();
       }
 
@@ -111,7 +113,7 @@ public class Consumer extends DestAbstract {
 
          connection.start();
 
-         int received = 0;
+         long received = 0;
 
          for (ConsumerThread thread : threadsArray) {
             thread.join();
@@ -122,6 +124,10 @@ public class Consumer extends DestAbstract {
             serializer.stop();
          }
 
+         if (outputStream != null) {
+            outputStream.close();
+         }
+
          return received;
       }
    }
