@@ -23,14 +23,16 @@ import org.apache.activemq.artemis.api.core.RoutingType;
 import org.apache.activemq.artemis.api.core.SimpleString;
 import org.apache.activemq.artemis.core.server.ComponentConfigurationRoutingType;
 import org.apache.activemq.artemis.utils.critical.CriticalAnalyzerPolicy;
-import org.jboss.logging.Logger;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
+import java.lang.invoke.MethodHandles;
 
 /**
  * Default values of ActiveMQ Artemis configuration parameters.
  */
 public final class ActiveMQDefaultConfiguration {
 
-   private static final Logger logger = Logger.getLogger(ActiveMQDefaultConfiguration.class);
+   private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
    /*
     * <p> In order to avoid compile time in-lining of constants, all access is done through methods
@@ -246,6 +248,9 @@ public final class ActiveMQDefaultConfiguration {
    // True means that the delivery count is persisted before delivery. False means that this only happens after a message has been cancelled.
    private static boolean DEFAULT_PERSIST_DELIVERY_COUNT_BEFORE_DELIVERY = false;
 
+   // Default Maximum number of records we would store for redeliveries
+   private static int DEFAULT_MAX_REDELIVERY_RECORDS = 10;
+
    // the directory to store paged messages in
    private static String DEFAULT_PAGING_DIR = "data/paging";
 
@@ -273,6 +278,8 @@ public final class ActiveMQDefaultConfiguration {
    // if true wait for transaction data to be synchronized to the journal before returning response to client
    private static boolean DEFAULT_JOURNAL_SYNC_TRANSACTIONAL = true;
 
+   private static boolean DEFAULT_LARGE_MESSAGE_SYNC = true;
+
    // if true wait for non transaction data to be synced to the journal before returning response to client.
    private static boolean DEFAULT_JOURNAL_SYNC_NON_TRANSACTIONAL = true;
 
@@ -401,20 +408,20 @@ public final class ActiveMQDefaultConfiguration {
    // If true then the server will request a backup on another node
    private static boolean DEFAULT_HAPOLICY_REQUEST_BACKUP = false;
 
-   // How many times the live server will try to request a backup, -1 means for ever.
+   // How many times this server will try to request a backup, -1 means for ever.
    private static int DEFAULT_HAPOLICY_BACKUP_REQUEST_RETRIES = -1;
 
    // How long to wait for retries between attempts to request a backup server.
    private static long DEFAULT_HAPOLICY_BACKUP_REQUEST_RETRY_INTERVAL = 5000;
 
-   // Whether or not this live server will accept backup requests from other live servers.
+   // Whether or not this server will accept backup requests from other servers.
    private static int DEFAULT_HAPOLICY_MAX_BACKUPS = 1;
 
    // The offset to use for the Connectors and Acceptors when creating a new backup server.
    private static int DEFAULT_HAPOLICY_BACKUP_PORT_OFFSET = 100;
 
-   // Whether to check the cluster for a (live) server using our own server ID when starting up. This option is only necessary for performing 'fail-back' on replicating servers. Strictly speaking this setting only applies to live servers and not to backups.
-   private static boolean DEFAULT_CHECK_FOR_LIVE_SERVER = false;
+   // Whether to check the cluster for an active server using our own server ID when starting up. This option is only necessary for performing 'fail-back' on replicating servers. Strictly speaking this setting only applies to primary servers and not to backups.
+   private static boolean DEFAULT_CHECK_FOR_ACTIVE_SERVER = false;
 
    // This specifies how many times a replicated backup server can restart after moving its files on start. Once there are this number of backup journal files the server will stop permanently after if fails back.
    private static int DEFAULT_MAX_SAVED_REPLICATED_JOURNALS_SIZE = 2;
@@ -428,10 +435,10 @@ public final class ActiveMQDefaultConfiguration {
    // When a replica comes online this is how long the replicating server will wait for a confirmation from the replica that the replication synchronization process is complete
    private static long DEFAULT_INITIAL_REPLICATION_SYNC_TIMEOUT = 30000;
 
-   // Will this backup server come live on a normal server shutdown
+   // Will this backup server become active on a normal server shutdown
    private static boolean DEFAULT_FAILOVER_ON_SERVER_SHUTDOWN = false;
 
-   // Will a shared-store master startup wait for activation
+   // Will a shared-store primary startup wait for activation
    private static boolean  DEFAULT_WAIT_FOR_ACTIVATION = true;
 
    // Will the broker populate the message with the name of the validated user
@@ -489,6 +496,10 @@ public final class ActiveMQDefaultConfiguration {
 
    private static final long DEFAULT_JDBC_LOCK_ACQUISITION_TIMEOUT_MILLIS = -1;
 
+   private static final long DEFAULT_JDBC_ALLOWED_TIME_DIFF_MILLIS = 250;
+
+   private static final int DEFAULT_JDBC_MAX_PAGE_SIZE_BYTES = 100 * 1024;
+
    // Default period to wait between connection TTL checks
    public static final long DEFAULT_CONNECTION_TTL_CHECK_INTERVAL = 2000;
 
@@ -509,12 +520,14 @@ public final class ActiveMQDefaultConfiguration {
          maxDisk = Integer.parseInt(System.getProperty(ActiveMQDefaultConfiguration.getDefaultSystemPropertyPrefix() + "maxDiskUsage", "90"));
       } catch (Throwable e) {
          // This is not really supposed to happen, so just logging it, just in case
-         logger.warn(e);
+         logger.warn(e.getMessage(), e);
          maxDisk = 90;
       }
       DEFAULT_MAX_DISK_USAGE = maxDisk;
    }
 
+   public static final long DEFAULT_MIN_DISK_FREE = -1;
+
    public static final int DEFAULT_DISK_SCAN = 5000;
 
    public static final int DEFAULT_MAX_QUEUE_CONSUMERS = -1;
@@ -533,6 +546,8 @@ public final class ActiveMQDefaultConfiguration {
 
    public static final boolean DEFAULT_ENABLED = true;
 
+   public static final boolean DEFAULT_INTERNAL = false;
+
    public static final boolean DEFAULT_QUEUE_AUTO_DELETE = true;
 
    public static final boolean DEFAULT_CREATED_QUEUE_AUTO_DELETE = false;
@@ -559,12 +574,18 @@ public final class ActiveMQDefaultConfiguration {
 
    public static final String DEFAULT_SYSTEM_PROPERTY_PREFIX = "brokerconfig.";
 
+   public static final String DEFAULT_SYSTEM_WEB_PROPERTY_PREFIX = "webconfig.";
+
    public static final String BROKER_PROPERTIES_SYSTEM_PROPERTY_NAME = "broker.properties";
 
    public static final String BROKER_PROPERTIES_KEY_SURROUND = "\"";
 
+   public static final String BROKER_PROPERTIES_REMOVE_VALUE = "-";
+
    public static final String BROKER_PROPERTIES_KEY_SURROUND_PROPERTY = "key.surround";
 
+   public static final String BROKER_PROPERTIES_REMOVE_VALUE_PROPERTY = "remove.value";
+
    public static String DEFAULT_NETWORK_CHECK_LIST = null;
 
    public static String DEFAULT_NETWORK_CHECK_URL_LIST = null;
@@ -646,12 +667,28 @@ public final class ActiveMQDefaultConfiguration {
    // Whether or not to report Netty pool metrics
    private static final boolean DEFAULT_NETTY_POOL_METRICS = false;
 
+   // Whether or not to report file descriptor metrics
+   private static final boolean DEFAULT_FILE_DESCRIPTORS_METRICS = false;
+
+   // Whether or not to report processor metrics
+   private static final boolean DEFAULT_PROCESSOR_METRICS = false;
+
+   // Whether or not to report uptime metrics
+   private static final boolean DEFAULT_UPTIME_METRICS = false;
+
    // How often (in ms) to scan for expired MQTT sessions
    private static long DEFAULT_MQTT_SESSION_SCAN_INTERVAL = 500;
 
+   // How long (in ms) to wait to persist MQTT session state
+   private static long DEFAULT_MQTT_SESSION_STATE_PERSISTENCE_TIMEOUT = 5000;
+
    // If SESSION-notifications should be suppressed or not
    public static boolean DEFAULT_SUPPRESS_SESSION_NOTIFICATIONS = false;
 
+   public static final long DEFAULT_EMBEDDED_WEB_SERVER_RESTART_TIMEOUT = 5000;
+
+   public static final String DEFAULT_LITERAL_MATCH_MARKERS = null;
+
    /**
     * If true then the ActiveMQ Artemis Server will make use of any Protocol Managers that are in available on the classpath. If false then only the core protocol will be available, unless in Embedded mode where users can inject their own Protocol Managers.
     */
@@ -673,6 +710,10 @@ public final class ActiveMQDefaultConfiguration {
       return DEFAULT_PERSISTENCE_ENABLED;
    }
 
+   public static int getDefaultMaxRedeliveryRecords() {
+      return DEFAULT_MAX_REDELIVERY_RECORDS;
+   }
+
    public static boolean isDefaultJournalDatasync() {
       return DEFAULT_JOURNAL_DATASYNC;
    }
@@ -983,6 +1024,10 @@ public final class ActiveMQDefaultConfiguration {
       return DEFAULT_JOURNAL_SYNC_TRANSACTIONAL;
    }
 
+   public static boolean isDefaultLargeMessageSync() {
+      return DEFAULT_LARGE_MESSAGE_SYNC;
+   }
+
    /**
     * if true wait for non transaction data to be synced to the journal before returning response to client.
     */
@@ -1288,7 +1333,7 @@ public final class ActiveMQDefaultConfiguration {
    }
 
    /**
-    * How many times the live server will try to request a backup, -1 means for ever.
+    * How many times the primary server will try to request a backup, -1 means for ever.
     */
    public static int getDefaultHapolicyBackupRequestRetries() {
       return DEFAULT_HAPOLICY_BACKUP_REQUEST_RETRIES;
@@ -1302,7 +1347,7 @@ public final class ActiveMQDefaultConfiguration {
    }
 
    /**
-    * Whether or not this live server will accept backup requests from other live servers.
+    * Whether or not this server will accept backup requests from other servers.
     */
    public static int getDefaultHapolicyMaxBackups() {
       return DEFAULT_HAPOLICY_MAX_BACKUPS;
@@ -1316,10 +1361,10 @@ public final class ActiveMQDefaultConfiguration {
    }
 
    /**
-    * Whether to check the cluster for a (live) server using our own server ID when starting up. This option is only necessary for performing 'fail-back' on replicating servers. Strictly speaking this setting only applies to live servers and not to backups.
+    * Whether to check the cluster for an active server using our own server ID when starting up. This option is only necessary for performing 'fail-back' on replicating servers. Strictly speaking this setting only applies to primary servers and not to backups.
     */
-   public static boolean isDefaultCheckForLiveServer() {
-      return DEFAULT_CHECK_FOR_LIVE_SERVER;
+   public static boolean isDefaultCheckForActiveServer() {
+      return DEFAULT_CHECK_FOR_ACTIVE_SERVER;
    }
 
    /**
@@ -1361,14 +1406,14 @@ public final class ActiveMQDefaultConfiguration {
    }
 
    /**
-    * Will this backup server come live on a normal server shutdown
+    * Will this backup server become active on a normal server shutdown
     */
    public static boolean isDefaultFailoverOnServerShutdown() {
       return DEFAULT_FAILOVER_ON_SERVER_SHUTDOWN;
    }
 
    /**
-    * Will a shared-store master startup wait for activation
+    * Will a shared-store primary startup wait for activation
     */
    public static boolean isDefaultWaitForActivation() {
       return DEFAULT_WAIT_FOR_ACTIVATION;
@@ -1478,6 +1523,14 @@ public final class ActiveMQDefaultConfiguration {
       return DEFAULT_JDBC_LOCK_ACQUISITION_TIMEOUT_MILLIS;
    }
 
+   public static long getDefaultJdbcAllowedTimeDiffMillis() {
+      return DEFAULT_JDBC_ALLOWED_TIME_DIFF_MILLIS;
+   }
+
+   public static int getDefaultJdbcMaxPageSizeBytes() {
+      return DEFAULT_JDBC_MAX_PAGE_SIZE_BYTES;
+   }
+
    public static long getDefaultConnectionTtlCheckInterval() {
       return DEFAULT_CONNECTION_TTL_CHECK_INTERVAL;
    }
@@ -1505,6 +1558,10 @@ public final class ActiveMQDefaultConfiguration {
       return DEFAULT_MAX_DISK_USAGE;
    }
 
+   public static long getDefaultMinDiskFree() {
+      return DEFAULT_MIN_DISK_FREE;
+   }
+
    public static int getDefaultDiskScanPeriod() {
       return DEFAULT_DISK_SCAN;
    }
@@ -1541,6 +1598,10 @@ public final class ActiveMQDefaultConfiguration {
       return DEFAULT_ENABLED;
    }
 
+   public static boolean getDefaultInternal() {
+      return DEFAULT_INTERNAL;
+   }
+
    public static boolean getDefaultQueueAutoDelete(boolean autoCreated) {
       return autoCreated ? getDefaultQueueAutoDelete() : getDefaultCreatedQueueAutoDelete();
    }
@@ -1605,10 +1666,18 @@ public final class ActiveMQDefaultConfiguration {
       return DEFAULT_SYSTEM_PROPERTY_PREFIX;
    }
 
+   public static String getDefaultSystemWebPropertyPrefix() {
+      return DEFAULT_SYSTEM_WEB_PROPERTY_PREFIX;
+   }
+
    public static String getDefaultBrokerPropertiesKeySurround() {
       return BROKER_PROPERTIES_KEY_SURROUND;
    }
 
+   public static String getDefaultBrokerPropertiesRemoveValue() {
+      return BROKER_PROPERTIES_REMOVE_VALUE;
+   }
+
    public static String getDefaultNetworkCheckList() {
       return DEFAULT_NETWORK_CHECK_LIST;
    }
@@ -1775,6 +1844,27 @@ public final class ActiveMQDefaultConfiguration {
       return DEFAULT_NETTY_POOL_METRICS;
    }
 
+   /**
+    * Whether or not to report file descriptor metrics
+    */
+   public static Boolean getDefaultFileDescriptorsMetrics() {
+      return DEFAULT_FILE_DESCRIPTORS_METRICS;
+   }
+
+   /**
+    * Whether or not to report processor metrics
+    */
+   public static Boolean getDefaultProcessorMetrics() {
+      return DEFAULT_PROCESSOR_METRICS;
+   }
+
+   /**
+    * Whether or not to report uptime metrics
+    */
+   public static Boolean getDefaultUptimeMetrics() {
+      return DEFAULT_UPTIME_METRICS;
+   }
+
    /**
     * How often (in ms) to scan for expired MQTT sessions
     */
@@ -1782,8 +1872,22 @@ public final class ActiveMQDefaultConfiguration {
       return DEFAULT_MQTT_SESSION_SCAN_INTERVAL;
    }
 
+   /**
+    * How long (in ms) to wait to persist MQTT session state
+    */
+   public static long getMqttSessionStatePersistenceTimeout() {
+      return DEFAULT_MQTT_SESSION_STATE_PERSISTENCE_TIMEOUT;
+   }
+
    public static boolean getDefaultSuppressSessionNotifications() {
       return DEFAULT_SUPPRESS_SESSION_NOTIFICATIONS;
    }
 
+   public static long getDefaultEmbeddedWebServerRestartTimeout() {
+      return DEFAULT_EMBEDDED_WEB_SERVER_RESTART_TIMEOUT;
+   }
+
+   public static String getLiteralMatchMarkers() {
+      return DEFAULT_LITERAL_MATCH_MARKERS;
+   }
 }
