@@ -30,7 +30,7 @@ import org.apache.maven.plugins.annotations.Mojo;
 import org.apache.maven.plugins.annotations.Parameter;
 import org.apache.maven.project.MavenProject;
 
-@Mojo(name = "cli", defaultPhase = LifecyclePhase.VERIFY)
+@Mojo(name = "cli", defaultPhase = LifecyclePhase.VERIFY, threadSafe = true)
 public class ArtemisCLIPlugin extends ArtemisAbstractPlugin {
 
    private PluginDescriptor descriptor;
@@ -89,18 +89,7 @@ public class ArtemisCLIPlugin extends ArtemisAbstractPlugin {
 
       MavenProject project = (MavenProject) getPluginContext().get("project");
 
-      if (!isArtemisHome(home.toPath())) {
-         if (isArtemisHome(alternateHome.toPath())) {
-            home = alternateHome;
-         } else {
-            getLog().error("********************************************************************************************");
-            getLog().error("Could not locate suitable Artemis.home on either " + home + " or " + alternateHome);
-            getLog().error("Use the binary distribution or build the distribution before running the examples");
-            getLog().error("********************************************************************************************");
-
-            throw new MojoExecutionException("Couldn't find artemis.home");
-         }
-      }
+      home = findArtemisHome(home, alternateHome);
 
       try {
          if (spawn) {
