@@ -60,7 +60,9 @@ import org.apache.activemq.artemis.core.persistence.OperationContext;
 import org.apache.activemq.artemis.core.persistence.QueueBindingInfo;
 import org.apache.activemq.artemis.core.persistence.AddressQueueStatus;
 import org.apache.activemq.artemis.core.persistence.StorageManager;
+import org.apache.activemq.artemis.core.persistence.config.AbstractPersistedAddressSetting;
 import org.apache.activemq.artemis.core.persistence.config.PersistedAddressSetting;
+import org.apache.activemq.artemis.core.persistence.config.PersistedAddressSettingJSON;
 import org.apache.activemq.artemis.core.persistence.config.PersistedBridgeConfiguration;
 import org.apache.activemq.artemis.core.persistence.config.PersistedConnector;
 import org.apache.activemq.artemis.core.persistence.config.PersistedDivertConfiguration;
@@ -305,11 +307,20 @@ public class SendAckFailTest extends SpawnedTestBase {
          manager.stop();
       }
 
+      @Override
+      public void asyncCommit(long txID) throws Exception {
+
+      }
+
       @Override
       public void updateQueueBinding(long tx, Binding binding) throws Exception {
          manager.updateQueueBinding(tx, binding);
       }
 
+      @Override
+      public void storeAddressSetting(PersistedAddressSettingJSON addressSetting) throws Exception {
+      }
+
       @Override
       public boolean isStarted() {
          return manager.isStarted();
@@ -685,7 +696,7 @@ public class SendAckFailTest extends SpawnedTestBase {
       }
 
       @Override
-      public List<PersistedAddressSetting> recoverAddressSettings() throws Exception {
+      public List<AbstractPersistedAddressSetting> recoverAddressSettings() throws Exception {
          return manager.recoverAddressSettings();
       }
 
