@@ -1,22 +1,22 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
  * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
  * the License.  You may obtain a copy of the License at
- * <p>
- * http://www.apache.org/licenses/LICENSE-2.0
- * <p>
+ *
+ *      http://www.apache.org/licenses/LICENSE-2.0
+ *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
  * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.activemq.artemis.tests.integration.mqtt5.spec.controlpackets;
 
+import java.lang.invoke.MethodHandles;
 import java.nio.charset.StandardCharsets;
 import java.util.ArrayList;
 import java.util.List;
@@ -43,11 +43,9 @@ import org.eclipse.paho.mqttv5.common.MqttMessage;
 import org.eclipse.paho.mqttv5.common.packet.MqttProperties;
 import org.eclipse.paho.mqttv5.common.packet.MqttReturnCode;
 import org.eclipse.paho.mqttv5.common.packet.UserProperty;
-import org.junit.Assume;
 import org.junit.Test;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
-import java.lang.invoke.MethodHandles;
 
 /**
  * Fulfilled by client or Netty codec (i.e. not tested here):
@@ -105,10 +103,6 @@ public class ConnectTests extends MQTT5TestSupport {
 
    private static final Logger logger = LoggerFactory.getLogger(MethodHandles.lookup().lookupClass());
 
-   public ConnectTests(String protocol) {
-      super(protocol);
-   }
-
    /*
     * [MQTT-3.1.2-7] If the Will Flag is set to 1 this indicates that, a Will Message MUST be stored on the Server and
     * associated with the Session.
@@ -633,9 +627,6 @@ public class ConnectTests extends MQTT5TestSupport {
     */
    @Test(timeout = DEFAULT_TIMEOUT)
    public void testEmptyClientID() throws Exception {
-      // This is apparently broken with the Paho client + web socket. The broker never even receives a CONNECT packet.
-      Assume.assumeTrue(protocol.equals(TCP));
-
       // no session should exist
       assertEquals(0, getSessionStates().size());
 
@@ -659,9 +650,6 @@ public class ConnectTests extends MQTT5TestSupport {
     */
    @Test(timeout = DEFAULT_TIMEOUT)
    public void testEmptyClientIDWithoutCleanStart() throws Exception {
-      // This is apparently broken with the Paho client + web socket. The broker never even receives a CONNECT packet.
-      Assume.assumeTrue(protocol.equals(TCP));
-
       // no session should exist
       assertEquals(0, getSessionStates().size());
 
@@ -739,6 +727,47 @@ public class ConnectTests extends MQTT5TestSupport {
       client2.disconnect();
    }
 
+   /*
+    * [MQTT-3.1.4-3] If the ClientID represents a Client already connected to the Server, the Server sends a DISCONNECT
+    * packet to the existing Client with Reason Code of 0x8E (Session taken over) as described in section 4.13 and MUST
+    * close the Network Connection of the existing Client.
+    */
+   @Test(timeout = DEFAULT_TIMEOUT)
+   public void testConnectionStealingBy3_1_1() throws Exception {
+      final String CLIENT_ID = RandomUtil.randomString();
+
+      MqttClient client = createPahoClient(CLIENT_ID);
+      client.connect();
+      final int[] reasonCode = new int[1];
+      CountDownLatch disconnectedLatch = new CountDownLatch(1);
+      client.setCallback(new LatchedMqttCallback(disconnectedLatch) {
+         @Override
+         public void disconnected(MqttDisconnectResponse disconnectResponse) {
+            reasonCode[0] = disconnectResponse.getReturnCode();
+            disconnectedLatch.countDown();
+         }
+
+         @Override
+         public void mqttErrorOccurred(MqttException exception) {
+            exception.printStackTrace();
+         }
+      });
+
+      org.eclipse.paho.client.mqttv3.MqttClient client2 = createPaho3_1_1Client(CLIENT_ID);
+      client2.connect();
+
+      assertTrue(disconnectedLatch.await(500, TimeUnit.MILLISECONDS));
+      assertEquals(MQTTReasonCodes.SESSION_TAKEN_OVER, (byte) reasonCode[0]);
+
+      // only 1 session should exist
+      assertEquals(1, getSessionStates().size());
+      assertNotNull(getSessionStates().get(CLIENT_ID));
+
+      assertFalse(client.isConnected());
+
+      client2.disconnect();
+   }
+
    /*
     * [MQTT-3.1.4-4] The Server MUST perform the processing of Clean Start.
     *
@@ -928,13 +957,20 @@ public class ConnectTests extends MQTT5TestSupport {
          .build();
       consumer.connect(options);
       consumer.subscribe(TOPIC, 2);
+      long start = System.currentTimeMillis();
       consumer.disconnect();
 
-      // session should *not* still exist since session expiry interval has passed
-      long start = System.currentTimeMillis();
+      // ensure the subscription queue still exists since the session hasn't expired
+      assertNotNull(getSubscriptionQueue(TOPIC, CONSUMER_ID));
+
       Wait.assertEquals(0, () -> getSessionStates().size(), EXPIRY_INTERVAL * 1000 * 2, 100);
-      assertTrue(System.currentTimeMillis() - start > (EXPIRY_INTERVAL * 1000));
+      assertTrue(System.currentTimeMillis() - start >= (EXPIRY_INTERVAL * 1000));
+
+      // session should *not* still exist since session expiry interval has passed
       assertNull(getSessionStates().get(CONSUMER_ID));
+
+      // ensure the subscription queue is cleaned up when the session expires
+      Wait.assertTrue(() -> getSubscriptionQueue(TOPIC, CONSUMER_ID) == null, 2000, 100);
    }
 
    /*
