@@ -34,6 +34,7 @@ import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
 import org.apache.activemq.artemis.api.config.ActiveMQDefaultConfiguration;
+import org.apache.activemq.artemis.api.core.JsonUtil;
 import org.apache.activemq.artemis.api.core.QueueConfiguration;
 import org.apache.activemq.artemis.api.core.RoutingType;
 import org.apache.activemq.artemis.api.core.SimpleString;
@@ -47,6 +48,7 @@ import org.apache.activemq.artemis.api.core.management.ActiveMQServerControl;
 import org.apache.activemq.artemis.api.core.management.ManagementHelper;
 import org.apache.activemq.artemis.api.core.management.ResourceNames;
 import org.apache.activemq.artemis.api.jms.ActiveMQJMSClient;
+import org.apache.activemq.artemis.core.management.impl.view.ProducerField;
 import org.apache.activemq.artemis.core.postoffice.Binding;
 import org.apache.activemq.artemis.core.postoffice.QueueBinding;
 import org.apache.activemq.artemis.core.postoffice.impl.LocalQueueBinding;
@@ -59,6 +61,8 @@ import org.apache.activemq.artemis.core.server.impl.ActiveMQServerImpl;
 import org.apache.activemq.artemis.core.server.impl.AddressInfo;
 import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
 import org.apache.activemq.artemis.jms.client.ActiveMQMessage;
+import org.apache.activemq.artemis.json.JsonArray;
+import org.apache.activemq.artemis.json.JsonObject;
 import org.apache.activemq.artemis.logs.AssertionLoggerHandler;
 import org.apache.activemq.artemis.reader.MessageUtil;
 import org.apache.activemq.artemis.spi.core.remoting.Acceptor;
@@ -163,10 +167,47 @@ public class StompTest extends StompTestBase {
       assertTrue(latch.await(60, TimeUnit.SECONDS));
    }
 
+   @Test
+   public void testProducerMetrics() throws Exception {
+      conn.connect(defUser, defPass);
+
+      send(conn, getQueuePrefix() + getQueueName(), null, "Hello World!", true);
+
+      String filterString = createJsonFilter("", "", "");
+      String producersAsJsonString = server.getActiveMQServerControl().listProducers(filterString, 1, 50);
+      JsonObject producersAsJsonObject = JsonUtil.readJsonObject(producersAsJsonString);
+      JsonArray array = (JsonArray) producersAsJsonObject.get("data");
+
+      Assert.assertEquals("number of producers returned from query", 1, array.size());
+
+      JsonObject producer = array.getJsonObject(0);
+      Assert.assertEquals(ProducerField.MESSAGE_SENT.getName(), 1, producer.getInt(ProducerField.MESSAGE_SENT.getName()));
+
+      send(conn, getQueuePrefix() + getQueueName(), null, "Hello World!", true);
+
+      producersAsJsonString = server.getActiveMQServerControl().listProducers(filterString, 1, 50);
+      producersAsJsonObject = JsonUtil.readJsonObject(producersAsJsonString);
+      array = (JsonArray) producersAsJsonObject.get("data");
+
+      Assert.assertEquals("number of producers returned from query", 1, array.size());
+
+      producer = array.getJsonObject(0);
+      Assert.assertEquals(ProducerField.MESSAGE_SENT.getName(), 2, producer.getInt(ProducerField.MESSAGE_SENT.getName()));
+
+      conn.closeTransport();
+
+      Wait.assertEquals(0, () -> ((JsonArray) JsonUtil.readJsonObject(server.getActiveMQServerControl().listProducers(filterString, 1, 50)).get("data")).size());
+
+      producersAsJsonString = server.getActiveMQServerControl().listProducers(filterString, 1, 50);
+      producersAsJsonObject = JsonUtil.readJsonObject(producersAsJsonString);
+      array = (JsonArray) producersAsJsonObject.get("data");
+
+      Assert.assertEquals("number of producers returned from query", 0, array.size());
+   }
+
    @Test
    public void testSendOverDiskFull() throws Exception {
-      AssertionLoggerHandler.startCapture();
-      try {
+      try (AssertionLoggerHandler loggerHandler = new AssertionLoggerHandler()) {
          MessageConsumer consumer = session.createConsumer(queue);
 
          conn.connect(defUser, defPass);
@@ -193,9 +234,7 @@ public class StompTest extends StompTestBase {
          }
          assertNotNull(e);
          // It should encounter the exception on logs
-         AssertionLoggerHandler.findText("AMQ119119");
-      } finally {
-         AssertionLoggerHandler.stopCapture();
+         loggerHandler.findText("AMQ119119");
       }
    }
 
@@ -305,6 +344,22 @@ public class StompTest extends StompTestBase {
 
    }
 
+   @Test
+   public void sendEmptyCoreMessage() throws Exception {
+      conn.connect(defUser, defPass);
+      subscribe(conn, null, Stomp.Headers.Subscribe.AckModeValues.AUTO);
+
+      // send core JMS message
+      MessageProducer mp = session.createProducer(session.createQueue(getQueuePrefix() + getQueueName()));
+      Message m = session.createMessage();
+      mp.send(m);
+
+      // Receive STOMP Message
+      ClientStompFrame frame = conn.receiveFrame();
+      assertNotNull(frame);
+      assertNull(frame.getBody());
+   }
+
    public void sendMessageToNonExistentQueue(String queuePrefix,
                                              String queue,
                                              RoutingType routingType) throws Exception {
@@ -665,6 +720,23 @@ public class StompTest extends StompTestBase {
 
    }
 
+   @Test
+   public void testNullPropertyValue() throws Exception {
+      conn.connect(defUser, defPass);
+
+      subscribe(conn, null, Stomp.Headers.Subscribe.AckModeValues.AUTO);
+
+      sendJmsMessage(getName(), "foo", null);
+
+      ClientStompFrame frame = conn.receiveFrame(2000);
+      Assert.assertEquals(Stomp.Responses.MESSAGE, frame.getCommand());
+      Assert.assertEquals(getQueuePrefix() + getQueueName(), frame.getHeader(Stomp.Headers.Send.DESTINATION));
+      Assert.assertEquals(getName(), frame.getBody());
+      Assert.assertEquals("", frame.getHeader("foo"));
+
+      conn.disconnect();
+   }
+
    @Test
    public void testTransactedSessionLeak() throws Exception {
       for (int i = 0; i < 10; i++) {
