@@ -1,12 +1,12 @@
-/**
+/*
  * Licensed to the Apache Software Foundation (ASF) under one or more
- * contributor license agreements. See the NOTICE file distributed with
+ * contributor license agreements.  See the NOTICE file distributed with
  * this work for additional information regarding copyright ownership.
  * The ASF licenses this file to You under the Apache License, Version 2.0
  * (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
+ * the License.  You may obtain a copy of the License at
  *
- * http://www.apache.org/licenses/LICENSE-2.0
+ *      http://www.apache.org/licenses/LICENSE-2.0
  *
  * Unless required by applicable law or agreed to in writing, software
  * distributed under the License is distributed on an "AS IS" BASIS,
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-
 package org.apache.activemq.artemis.tests.smoke.quorum;
 
 import javax.management.remote.JMXServiceURL;
+import java.io.File;
 import java.net.MalformedURLException;
 import java.util.Arrays;
-import java.util.LinkedList;
+import java.util.List;
 import java.util.Objects;
 import java.util.Optional;
 import java.util.concurrent.TimeUnit;
@@ -31,9 +31,11 @@ import org.apache.activemq.artemis.tests.smoke.common.SmokeTestBase;
 import org.apache.activemq.artemis.tests.util.Jmx;
 import org.apache.activemq.artemis.util.ServerUtil;
 import org.apache.activemq.artemis.utils.Wait;
+import org.apache.activemq.artemis.utils.cli.helper.HelperCreate;
 import org.junit.After;
 import org.junit.Assert;
 import org.junit.Before;
+import org.junit.BeforeClass;
 import org.junit.Test;
 import org.junit.runner.RunWith;
 import org.junit.runners.Parameterized;
@@ -44,10 +46,10 @@ import java.lang.invoke.MethodHandles;
 import static org.apache.activemq.artemis.tests.util.Jmx.backupOf;
 import static org.apache.activemq.artemis.tests.util.Jmx.containsExactNodeIds;
 import static org.apache.activemq.artemis.tests.util.Jmx.decodeNetworkTopologyJson;
-import static org.apache.activemq.artemis.tests.util.Jmx.liveOf;
+import static org.apache.activemq.artemis.tests.util.Jmx.primaryOf;
 import static org.apache.activemq.artemis.tests.util.Jmx.validateNetworkTopology;
 import static org.apache.activemq.artemis.tests.util.Jmx.withBackup;
-import static org.apache.activemq.artemis.tests.util.Jmx.withLive;
+import static org.apache.activemq.artemis.tests.util.Jmx.withPrimary;
 import static org.apache.activemq.artemis.tests.util.Jmx.withMembers;
 import static org.apache.activemq.artemis.tests.util.Jmx.withNodes;
 
@@ -66,6 +68,29 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
    static final int PRIMARY_PORT_OFFSET = 0;
    static final int BACKUP_PORT_OFFSET = PRIMARY_PORT_OFFSET + 100;
 
+   public static void simpleCreate(String serverName) throws Exception {
+
+      File server0Location = getFileServerLocation(serverName);
+      deleteDirectory(server0Location);
+
+      {
+         HelperCreate cliCreateServer = new HelperCreate();
+         cliCreateServer.setUser("admin").setPassword("admin").setAllowAnonymous(true).setNoWeb(true).setArtemisInstance(server0Location).
+            setConfiguration("./src/main/resources/servers/" + serverName);
+         cliCreateServer.setArgs("--java-options", "-Djava.rmi.server.hostname=localhost");
+         cliCreateServer.createServer();
+      }
+   }
+
+   @BeforeClass
+   public static void createServers() throws Exception {
+      simpleCreate("zkReplicationPrimary");
+      simpleCreate("zkReplicationPrimaryPeerA");
+      simpleCreate("zkReplicationPrimaryPeerB");
+      simpleCreate("zkReplicationBackup");
+   }
+
+
    public static class BrokerControl {
 
       final String name;
@@ -129,12 +154,12 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
 
    protected BrokerControl primary;
    protected BrokerControl backup;
-   protected LinkedList<BrokerControl> brokers;
+   protected List<BrokerControl> brokers;
 
    public PluggableQuorumSinglePairTest(String brokerFolderPrefix) {
       primary = new BrokerControl("primary", JMX_PORT_PRIMARY, brokerFolderPrefix + PRIMARY_DATA_FOLDER, PRIMARY_PORT_OFFSET);
       backup = new BrokerControl("backup", JMX_PORT_BACKUP, brokerFolderPrefix + BACKUP_DATA_FOLDER, BACKUP_PORT_OFFSET);
-      brokers = new LinkedList(Arrays.asList(primary, backup));
+      brokers = Arrays.asList(primary, backup);
    }
 
    protected abstract boolean awaitAsyncSetupCompleted(long timeout, TimeUnit unit) throws InterruptedException;
@@ -158,11 +183,11 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
    public void testCanQueryEmptyBackup() throws Exception {
       final int timeout = (int) TimeUnit.SECONDS.toMillis(30);
       logger.info("starting primary");
-      Process live = primary.startServer(this, timeout);
+      Process primary = this.primary.startServer(this, timeout);
       Assert.assertTrue(awaitAsyncSetupCompleted(timeout, TimeUnit.MILLISECONDS));
-      Wait.assertTrue(() -> !primary.isBackup().orElse(true), timeout);
+      Wait.assertTrue(() -> !this.primary.isBackup().orElse(true), timeout);
       logger.info("killing primary");
-      ServerUtil.killServer(live, forceKill);
+      ServerUtil.killServer(primary, forceKill);
       logger.info("starting backup");
       backup.startServer(this, 0);
       Wait.assertTrue(() -> backup.isBackup().orElse(false), timeout);
@@ -194,7 +219,7 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
       for (BrokerControl broker : brokers) {
          Wait.assertTrue(() -> validateNetworkTopology(broker.listNetworkTopology().orElse(""),
                                                            containsExactNodeIds(nodeID)
-                                                          .and(withLive(nodeID, Objects::nonNull))
+                                                          .and(withPrimary(nodeID, Objects::nonNull))
                                                           .and(withBackup(nodeID, Objects::nonNull))
                                                           .and(withMembers(1))
                                                           .and(withNodes(2))), timeout);
@@ -206,7 +231,7 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
       final String urlBackup = backupOf(nodeID, decodeNetworkTopologyJson(backup.listNetworkTopology().get()));
       Assert.assertNotNull(urlBackup);
       logger.info("backup: {}", urlBackup);
-      final String urlPrimary = liveOf(nodeID, decodeNetworkTopologyJson(primary.listNetworkTopology().get()));
+      final String urlPrimary = primaryOf(nodeID, decodeNetworkTopologyJson(primary.listNetworkTopology().get()));
       Assert.assertNotNull(urlPrimary);
       logger.info("primary: {}", urlPrimary);
       Assert.assertNotEquals(urlPrimary, urlBackup);
@@ -221,7 +246,7 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
       Wait.assertTrue(() -> !backup.isBackup().orElse(true), timeout);
       Wait.assertTrue(() -> validateNetworkTopology(backup.listNetworkTopology().orElse(""),
                                                     containsExactNodeIds(nodeID)
-                                                       .and(withLive(nodeID, urlBackup::equals))
+                                                       .and(withPrimary(nodeID, urlBackup::equals))
                                                        .and(withBackup(nodeID, Objects::isNull))
                                                        .and(withMembers(1))
                                                        .and(withNodes(1))), timeout);
@@ -242,7 +267,7 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
       for (BrokerControl broker : brokers) {
          Wait.assertTrue(() -> validateNetworkTopology(broker.listNetworkTopology().orElse(""),
                                                        containsExactNodeIds(nodeID)
-                                                          .and(withLive(nodeID, urlPrimary::equals))
+                                                          .and(withPrimary(nodeID, urlPrimary::equals))
                                                           .and(withBackup(nodeID, urlBackup::equals))
                                                           .and(withMembers(1))
                                                           .and(withNodes(2))), timeout);
@@ -263,7 +288,7 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
    }
 
    @Test
-   public void testLivePrimarySuicideOnLostQuorum() throws Exception {
+   public void testActivePrimarySuicideOnLostQuorum() throws Exception {
       final int timeout = (int) TimeUnit.SECONDS.toMillis(30);
       Process primaryInstance = primary.startServer(this, timeout);
       Assert.assertTrue(awaitAsyncSetupCompleted(timeout, TimeUnit.MILLISECONDS));
@@ -271,14 +296,14 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
       final String nodeID = primary.getNodeID().get();
       Wait.assertTrue(() -> validateNetworkTopology(primary.listNetworkTopology().orElse(""),
                                                     containsExactNodeIds(nodeID)
-                                                       .and(withLive(nodeID, Objects::nonNull))
+                                                       .and(withPrimary(nodeID, Objects::nonNull))
                                                        .and(withBackup(nodeID, Objects::isNull))
                                                        .and(withMembers(1))
                                                        .and(withNodes(1))), timeout);
-      final String urlLive = liveOf(nodeID, decodeNetworkTopologyJson(primary.listNetworkTopology().get()));
+      final String urlPrimary = primaryOf(nodeID, decodeNetworkTopologyJson(primary.listNetworkTopology().get()));
       Assert.assertTrue(validateNetworkTopology(primary.listNetworkTopology().orElse(""),
                                                 containsExactNodeIds(nodeID)
-                                                   .and(withLive(nodeID, urlLive::equals))
+                                                   .and(withPrimary(nodeID, urlPrimary::equals))
                                                    .and(withBackup(nodeID, Objects::isNull))
                                                    .and(withMembers(1))
                                                    .and(withNodes(1))));
@@ -287,7 +312,7 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
    }
 
    @Test
-   public void testLiveBackupSuicideOnLostQuorum() throws Exception {
+   public void testActiveBackupSuicideOnLostQuorum() throws Exception {
       final int timeout = (int) TimeUnit.SECONDS.toMillis(30);
       Process primaryInstance = primary.startServer(this, timeout);
       Assert.assertTrue(awaitAsyncSetupCompleted(timeout, TimeUnit.MILLISECONDS));
@@ -299,7 +324,7 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
       for (BrokerControl broker : brokers) {
          Wait.assertTrue(() -> validateNetworkTopology(broker.listNetworkTopology().orElse(""),
                                                        containsExactNodeIds(nodeID)
-                                                          .and(withLive(nodeID, Objects::nonNull))
+                                                          .and(withPrimary(nodeID, Objects::nonNull))
                                                           .and(withBackup(nodeID, Objects::nonNull))
                                                           .and(withMembers(1))
                                                           .and(withNodes(2))), timeout);
@@ -307,14 +332,14 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
       Assert.assertTrue(backup.isReplicaSync().get());
       final String urlBackup = backupOf(nodeID, decodeNetworkTopologyJson(backup.listNetworkTopology().get()));
       Assert.assertNotNull(urlBackup);
-      final String urlPrimary = liveOf(nodeID, decodeNetworkTopologyJson(primary.listNetworkTopology().get()));
+      final String urlPrimary = primaryOf(nodeID, decodeNetworkTopologyJson(primary.listNetworkTopology().get()));
       Assert.assertNotNull(urlPrimary);
       Assert.assertNotEquals(urlPrimary, urlBackup);
       ServerUtil.killServer(primaryInstance, forceKill);
       Wait.assertTrue(() -> !backup.isBackup().orElse(true), timeout);
       Wait.assertTrue(() -> validateNetworkTopology(backup.listNetworkTopology().orElse(""),
                                                     containsExactNodeIds(nodeID)
-                                                       .and(withLive(nodeID, urlBackup::equals))
+                                                       .and(withPrimary(nodeID, urlBackup::equals))
                                                        .and(withBackup(nodeID, Objects::isNull))
                                                        .and(withMembers(1))
                                                        .and(withNodes(1))), timeout);
@@ -341,7 +366,7 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
       for (BrokerControl broker : brokers) {
          Wait.assertTrue(() -> validateNetworkTopology(broker.listNetworkTopology().orElse(""),
                                                        containsExactNodeIds(nodeID)
-                                                          .and(withLive(nodeID, Objects::nonNull))
+                                                          .and(withPrimary(nodeID, Objects::nonNull))
                                                           .and(withBackup(nodeID, Objects::nonNull))
                                                           .and(withMembers(1))
                                                           .and(withNodes(2))), timeout);
@@ -353,7 +378,7 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
       final String urlBackup = backupOf(nodeID, decodeNetworkTopologyJson(backup.listNetworkTopology().get()));
       Assert.assertNotNull(urlBackup);
       logger.info("backup: {}", urlBackup);
-      final String urlPrimary = liveOf(nodeID, decodeNetworkTopologyJson(primary.listNetworkTopology().get()));
+      final String urlPrimary = primaryOf(nodeID, decodeNetworkTopologyJson(primary.listNetworkTopology().get()));
       Assert.assertNotNull(urlPrimary);
       logger.info("primary: {}", urlPrimary);
       Assert.assertNotEquals(urlPrimary, urlBackup);
@@ -369,7 +394,7 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
       Wait.assertTrue(() -> !backup.isBackup().orElse(true), timeout);
       Wait.assertTrue(() -> validateNetworkTopology(backup.listNetworkTopology().orElse(""),
                                                     containsExactNodeIds(nodeID)
-                                                       .and(withLive(nodeID, urlBackup::equals))
+                                                       .and(withPrimary(nodeID, urlBackup::equals))
                                                        .and(withBackup(nodeID, Objects::isNull))
                                                        .and(withMembers(1))
                                                        .and(withNodes(1))), timeout);
@@ -406,4 +431,3 @@ public abstract class PluggableQuorumSinglePairTest extends SmokeTestBase {
       Assert.assertEquals(3L, backup.getActivationSequence().get().longValue());
    }
 }
-
